# Changelog

## [0.2.0] - 2022/09/15

### Added

- `raspunzel build` command
- `raspunzel sync` command
- Cosmetic logging submodule

### Changed

- Refactor Bazel functions to submodule
- Remove dependency on colorama

## [0.1.0] - 2022/08/18

First release of the project.
